<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KonqIconView" version="13">
<MenuBar>
 <Menu name="edit"><text>&amp;Edit</text>
   <Menu name="selection"><text>Selection</text>
     <Action name="select"/>
     <Action name="unselect"/>
     <Separator/>
     <Action name="selectall"/>
     <Action name="unselectall"/>
     <Action name="invertselection"/>
   </Menu>
 </Menu>
 <Menu name="view"><text>&amp;View</text>
  <Menu name="iconview_mode"><text>&amp;Icon Size</text>
   <Action name="modedefault"/>
   <Separator/>
   <Action name="modeenormous"/>
   <Action name="modehuge"/>
   <Action name="modelarge"/>
   <Action name="modemedium"/>
   <Action name="modesmallmedium"/>
   <Action name="modesmall"/>
  </Menu>
  <Menu name="iconview_sort"><text>S&amp;ort</text>
   <Action name="sort_nc"/>
   <Action name="sort_nci"/>
   <Action name="sort_size"/>
   <Action name="sort_type"/>
   <Action name="sort_date"/>
   <Separator/>
   <Action name="sort_descend"/>
   <Separator/>
   <Action name="sort_directoriesfirst" />
  </Menu>
  <Action name="iconview_preview" />
  <Action name="show_dot"/>
  <Action name="show_directory_overlays"/>
  <Separator/>
  <Action name="bgsettings"/>
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Iconview Toolbar</text>
 <Separator/>
 <Action name="incIconSize" />
 <Action name="decIconSize" />
</ToolBar>
<ToolBar name="extraToolBar"><text>Iconview Extra Toolbar</text>
 <Action name="iconview_preview_all" />
</ToolBar>
</kpartgui>
